@@ -332,6 +332,8 @@ class Scan:
             else:
                 self.n_pixels[i] = im.n_pixel.n
         self.R = np.delete(self.R, to_remove)
+        self.theta = np.delete(self.theta, to_remove)
+        self.n_pixels = np.delete(self.n_pixels, to_remove)
         self.q = np.delete(self.q, to_remove)
 
     def footprint_correction(self, beam_width, sample_size):
